.. veliberator documentation master file, created by
   sphinx-quickstart on Tue Aug 23 22:12:33 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to veliberator's documentation!
=======================================

.. toctree::
   :maxdepth: 2

   Presentation <overview>
   Development <buildout>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

